#!/usr/bin/env python
########################################################################
# File :    dirac-dms-get-file
# Author :  Stuart Paterson
########################################################################
"""
Retrieve a single file or list of files from Grid storage to the current directory.

Example:
  $ dirac-dms-get-file /formation/user/v/vhamar/Example.txt
  {'Failed': {},
   'Successful': {'/formation/user/v/vhamar/Example.txt': '/afs/in2p3.fr/home/h/hamar/Tests/DMS/Example.txt'}}
"""
import DIRAC
from DIRAC.Core.Base.Script import Script


def main():
    # Registering arguments will automatically add their description to the help menu
    Script.registerArgument(["LFN:      Logical File Name or file containing LFNs"])
    Script.parseCommandLine(ignoreErrors=True)
    lfns = Script.getPositionalArgs()

    if len(lfns) < 1:
        Script.showHelp()

    exitCode = 0

    if len(lfns) == 1:
        try:
            with open(lfns[0]) as f:
                lfns = f.read().splitlines()
        except Exception:
            pass
    from DIRAC.DataManagementSystem.Client.DataManager import DataManager
    dm = DataManager(vo="vo.cta.in2p3.fr")
    res = dm.getFile(lfns)
    print(res)
    if not res["OK"]:
        print(f"ERROR {result['Message']}")
        exitCode = 2

    DIRAC.exit(exitCode)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
"""
Check problematic files

To be tested for merged step 1

Usage:
   cta-prod-check-problematic <trans_id> <output data level>
   <output data level> must be : DL1, DL2, merged
"""

__RCSID__ = "$Id$"

import os
import DIRAC
from DIRAC import gLogger
from DIRAC.Core.Base.Script import Script
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Resources.Catalog.FileCatalogClient import FileCatalogClient
from DIRAC.TransformationSystem.Client import TransformationFilesStatus
from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient


def main():
    Script.parseCommandLine(ignoreErrors=True)
    argss = Script.getPositionalArgs()
    fcc = FileCatalogClient()

    trans_client = TransformationClient()
    lfn_list = []
    if len(argss) == 2:
        trans_id = argss[0]
        if argss[1] in ["DL1", "DL2", "merged"]:
            out_data_level = argss[1]
        else:
            DIRAC.gLogger.error(f"Second argument must be in : DL1, DL2, merged")
    else:
        Script.showHelp()



    cond_dict = {"TransformationID": trans_id, "Status" : "Problematic"}

    res = trans_client.getTransformationFiles(cond_dict)
    for lfn_dict in res["Value"]:
        lfn_list.append(lfn_dict["LFN"])

    lfn_0 = lfn_list[0]
    if out_data_level == "DL1":
        out_path = os.path.dirname(lfn_0).split("sim_telarray")[0]
    elif out_data_level == "DL2":
        out_path = os.path.dirname(lfn_0).split("ctapipe-process")[0]
    elif out_data_level == "merged":
        out_path = os.path.dirname(lfn_0).split("ctapipe-process")[0]
    if out_data_level in ["DL1", "DL2"]:
        out_path = os.path.join(out_path, "ctapipe-process", trans_id)
    elif out_data_level == "merged":
        out_path = os.path.join(out_path, "ctapipe-merge", trans_id)

    DIRAC.gLogger.notice(f"Output path : {out_path}")
    DIRAC.gLogger.notice(f"First input file : {lfn_0}")
    res = fcc.getFileUserMetadata(lfn_0)
    if not res["OK"]:
        DIRAC.gLogger.warn(f"Failed to get user metadata for {lfn_0}")
        DIRAC.exit(1)

    nsb_value = res["Value"]["nsb"]
    metadata_dict = {"nsb" : int(nsb_value)}
    if "split" in res["Value"]:
        split_value = res["Value"]["split"]
        metadata_dict.update({"split": split_value})

    if out_data_level == "merged":
        in_file_name = os.path.basename(lfn_0)
        data_dir = os.path.dirname(lfn_0).split("/")[-2:]
        data_path = os.path.join(data_dir[0], data_dir[1])
        out_file_name = in_file_name.replace("DL2.h5","merged.DL2.h5")
        out_lfn = os.path.join(out_path, data_path, out_file_name)
        res = fcc.exists(out_lfn)
        if res["Value"]["Successful"][out_lfn]:
            DIRAC.gLogger.notice(f"{out_lfn} found. Set metadata")
            res = fcc.setMetadata(out_lfn, metadata_dict)
            if not res["OK"]:
                DIRAC.gLogger.warn(f"Failed to set metadata")
            for lfn in lfn_list:
                res = trans_client.setFileStatusForTransformation(
                    trans_id, TransformationFilesStatus.PROCESSED, lfn
                )
                if not res["OK"]:
                    DIRAC.gLogger.warn(f"Failed to set file status to PROCESSED {lfn}")
        else:
            DIRAC.gLogger.notice(f"{out_lfn} not found")
    else:
        for lfn in lfn_list:
            in_file_name = os.path.basename(lfn)
            data_dir = os.path.dirname(lfn).split("/")[-2:]
            data_path = os.path.join(data_dir[0], data_dir[1])
            if out_data_level == "DL1":
                out_file_name = in_file_name.replace("simtel.zst","DL1.h5")
            elif out_data_level == "DL2":
                out_file_name = in_file_name.replace("DL1.h5","DL2.h5")
            out_lfn = os.path.join(out_path, data_path, out_file_name)
            res = fcc.exists(out_lfn)
            if res["Value"]["Successful"][out_lfn]:
                DIRAC.gLogger.notice(f"{out_lfn} found, set metadata")
                res = fcc.setMetadata(out_lfn, metadata_dict)
                if not res["OK"]:
                    DIRAC.gLogger.warn(f"Failed to set metadata")
                res = trans_client.setFileStatusForTransformation(
                    trans_id, TransformationFilesStatus.PROCESSED, lfn
                )
                if not res["OK"]:
                    DIRAC.gLogger.warn(f"Failed to set file status to PROCESSED {lfn}")
            else:
                DIRAC.gLogger.notice(f"{out_lfn} not found")

    DIRAC.exit()


####################################################
if __name__ == "__main__":
    main()



#!/usr/bin/env python

__RCSID__ = "$Id$"

# generic imports
from multiprocessing import Pool

# DIRAC imports
from DIRAC import gLogger
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Core.Base.Script import Script

Script.setUsageMessage(
    """
Register files in the catalog
Usage:
   cta-prod-register-file <ascii file with lfn list>
"""
)

Script.parseCommandLine(ignoreErrors=True)
# Must comes after parseCommandLine
from DIRAC.Resources.Catalog.FileCatalog import FileCatalog

fc = FileCatalog()


def registerFile(lfn, metadata_dict):



    #PFN = metadata_dict["PFN"]
    SE = metadata_dict["SE"]
    Size = metadata_dict["Size"]
    GUID = metadata_dict["GUID"]
    Checksum = metadata_dict["Checksum"]
    lfn_dict = {lfn: {'PFN': PFN, 'SE': SE, 'Size': Size, 'GUID': GUID, 'Checksum': Checksum}}
    print(lfn_dict)
    #res = fc.addFile(lfn)


def getFileMetadata(lfn):
    res = fc.getFileMetadata(lfn)
    metadata_dict = res["Value"]["Successful"][lfn]
    return metadata_dict

def getReplicas(lfn):
    res = fc.getReplicas(lfn)
    replica_dict = res["Value"]
    print(replica_dict)
    return replica_dict


def main():
    #args = Script.getPositionalArgs()
    #if len(args) > 0:
    #    infile = args[0]
    #else:
    #    Script.showHelp()

    #infileList = read_inputs_from_file(infile)
    #p = Pool(1)
    #p.map(registerFile, infileList)
    lfn = "/vo.cta.in2p3.fr/user/a/arrabito/testPIC-Disk.txt"
    metadata_dict = getFileMetadata(lfn)
    replica_dict = getReplicas(lfn)
    #lfn_dict = {lfn: {'PFN':, 'SE':, 'Size':, 'GUID':, 'Checksum': }}
    #registerFile(lfn, metadata_dict)

if __name__ == "__main__":
    main()
